# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.actor import Actor


class AxisActor(Actor):
    """
    AxisActor - Create an axis with tick marks and labels
    
    Superclass: Actor
    
    AxisActor creates an axis with tick marks, labels, and/or a title,
    depending on the particular instance variable settings. It is assumed
    that the axes is part of a bounding box and is orthoganal to one of
    the coordinate axes.  To use this class, you typically specify two
    points defining the start and end points of the line (xyz definition
    using Coordinate class), the axis type (X, Y or Z), the axis
    location in relation to the bounding box, the bounding box, the
    number of labels, and the data range (min,max). You can also control
    what parts of the axis are visible including the line, the tick
    marks, the labels, and the title. It is also possible to control
    gridlines, and specifiy on which 'side' the tickmarks are drawn
    (again with respect to the underlying assumed bounding box). You can
    also specify the label format (a printf style format).
    
    This class decides how to locate the labels, and how to create
    reasonable tick marks and labels.
    
    Labels follow the camera so as to be legible from any viewpoint.
    
    The instance variables Point1 and Point2 are instances of
    Coordinate. All calculations and references are in World
    Coordinates.
    
    Thanks:
    
    This class was written by: Hank Childs, Kathleen Bonnell, Amy
    Squillacote, Brad Whitlock, Eric Brugger, Claire Guilbaud, Nicolas
    Dolegieviez, Will Schroeder, Karthik Krishnan, Aashish Chaudhary,
    Philippe Pbay, David Gobbi, David Partyka, Utkarsh Ayachit David
    Cole, Franois Bertel, and Mark Olesen
    
    See Also:
    
    Actor VectorText PolyDataMapper AxisActor2D Coordinate
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkAxisActor, obj, update, **traits)
    
    tick_visibility = tvtk_base.true_bool_trait(help=\
        """
        Set/Get visibility of the axis tick marks.
        """
    )
    def _tick_visibility_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTickVisibility,
                        self.tick_visibility_)

    draw_gridpolys = tvtk_base.false_bool_trait(help=\
        """
        Set/Get whether gridpolys should be drawn.
        """
    )
    def _draw_gridpolys_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetDrawGridpolys,
                        self.draw_gridpolys_)

    label_visibility = tvtk_base.true_bool_trait(help=\
        """
        Set/Get visibility of the axis labels.
        """
    )
    def _label_visibility_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetLabelVisibility,
                        self.label_visibility_)

    draw_inner_gridlines = tvtk_base.false_bool_trait(help=\
        """
        Set/Get whether inner gridlines should be drawn.
        """
    )
    def _draw_inner_gridlines_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetDrawInnerGridlines,
                        self.draw_inner_gridlines_)

    axis_visibility = tvtk_base.true_bool_trait(help=\
        """
        Set/Get visibility of the axis line.
        """
    )
    def _axis_visibility_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetAxisVisibility,
                        self.axis_visibility_)

    title_visibility = tvtk_base.true_bool_trait(help=\
        """
        Set/Get visibility of the axis title.
        """
    )
    def _title_visibility_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTitleVisibility,
                        self.title_visibility_)

    calculate_label_offset = tvtk_base.true_bool_trait(help=\
        """
        Set/Get flag whether to calculate label offset. Default is true.
        """
    )
    def _calculate_label_offset_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetCalculateLabelOffset,
                        self.calculate_label_offset_)

    draw_gridlines = tvtk_base.false_bool_trait(help=\
        """
        Set/Get whether gridlines should be drawn.
        """
    )
    def _draw_gridlines_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetDrawGridlines,
                        self.draw_gridlines_)

    calculate_title_offset = tvtk_base.true_bool_trait(help=\
        """
        Set/Get flag whether to calculate title offset. Default is true.
        """
    )
    def _calculate_title_offset_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetCalculateTitleOffset,
                        self.calculate_title_offset_)

    minor_ticks_visible = tvtk_base.true_bool_trait(help=\
        """
        Set/Get the flag that controls whether the minor ticks are
        visible.
        """
    )
    def _minor_ticks_visible_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetMinorTicksVisible,
                        self.minor_ticks_visible_)

    axis_type = traits.Trait('x',
    tvtk_base.TraitRevPrefixMap({'y': 1, 'x': 0, 'z': 2}), help=\
        """
        Set/Get the type of this axis.
        """
    )
    def _axis_type_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetAxisType,
                        self.axis_type_)

    tick_location = traits.Trait('inside',
    tvtk_base.TraitRevPrefixMap({'both': 2, 'inside': 0, 'outside': 1}), help=\
        """
        Set/Get the location of the ticks.
        """
    )
    def _tick_location_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTickLocation,
                        self.tick_location_)

    axis_position = traits.Trait('min_min',
    tvtk_base.TraitRevPrefixMap({'max_min': 3, 'min_max': 1, 'max_max': 2, 'min_min': 0}), help=\
        """
        Set/Get the position of this axis (in relation to an an assumed
        bounding box).  For an x-type axis, MINMIN corresponds to the
        x-edge in the bounding box where Y values are minimum and Z
        values are minimum. For a y-type axis, MAXMIN corresponds to the
        y-edge where X values are maximum and Z values are minimum.
        """
    )
    def _axis_position_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetAxisPosition,
                        self.axis_position_)

    major_tick_size = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the size of the major tick marks
        """
    )
    def _major_tick_size_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetMajorTickSize,
                        self.major_tick_size)

    def _get_gridpolys_property(self):
        return wrap_vtk(self._vtk_obj.GetGridpolysProperty())
    def _set_gridpolys_property(self, arg):
        old_val = self._get_gridpolys_property()
        self._wrap_call(self._vtk_obj.SetGridpolysProperty,
                        deref_vtk(arg))
        self.trait_property_changed('gridpolys_property', old_val, arg)
    gridpolys_property = traits.Property(_get_gridpolys_property, _set_gridpolys_property, help=\
        """
        Get/Set grid_polys actor property (grid quads)
        """
    )

    title = traits.Trait(None, None, traits.String(enter_set=True, auto_set=False), help=\
        """
        Set/Get the title of the axis actor,
        """
    )
    def _title_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTitle,
                        self.title)

    delta_minor = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        
        """
    )
    def _delta_minor_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetDeltaMinor,
                        self.delta_minor)

    def _get_camera(self):
        return wrap_vtk(self._vtk_obj.GetCamera())
    def _set_camera(self, arg):
        old_val = self._get_camera()
        self._wrap_call(self._vtk_obj.SetCamera,
                        deref_vtk(arg))
        self.trait_property_changed('camera', old_val, arg)
    camera = traits.Property(_get_camera, _set_camera, help=\
        """
        Set/Get the camera for this axis.  The camera is used by the
        labels to 'follow' the camera and be legible from any viewpoint.
        """
    )

    minor_range_start = traits.Float(0.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the starting position for minor and major tick points on
        the range and the delta values that determine their spacing. The
        range and the position need not be identical. ie the displayed
        values need not match the actual positions in 3d space.
        """
    )
    def _minor_range_start_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetMinorRangeStart,
                        self.minor_range_start)

    vertical_offset_x_title2d = traits.Float(-40.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the 2d mode the vertical offset for X title in 2d mode
        """
    )
    def _vertical_offset_x_title2d_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetVerticalOffsetXTitle2D,
                        self.vertical_offset_x_title2d)

    minor_tick_size = traits.Float(0.5, enter_set=True, auto_set=False, help=\
        """
        Set/Get the size of the major tick marks
        """
    )
    def _minor_tick_size_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetMinorTickSize,
                        self.minor_tick_size)

    horizontal_offset_y_title2d = traits.Float(-50.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the 2d mode the horizontal offset for Y title in 2d mode
        """
    )
    def _horizontal_offset_y_title2d_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetHorizontalOffsetYTitle2D,
                        self.horizontal_offset_y_title2d)

    delta_range_minor = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the starting position for minor and major tick points on
        the range and the delta values that determine their spacing. The
        range and the position need not be identical. ie the displayed
        values need not match the actual positions in 3d space.
        """
    )
    def _delta_range_minor_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetDeltaRangeMinor,
                        self.delta_range_minor)

    def _get_gridlines_property(self):
        return wrap_vtk(self._vtk_obj.GetGridlinesProperty())
    def _set_gridlines_property(self, arg):
        old_val = self._get_gridlines_property()
        self._wrap_call(self._vtk_obj.SetGridlinesProperty,
                        deref_vtk(arg))
        self.trait_property_changed('gridlines_property', old_val, arg)
    gridlines_property = traits.Property(_get_gridlines_property, _set_gridlines_property, help=\
        """
        Get/Set gridlines actor property (outer grid lines)
        """
    )

    def _get_inner_gridlines_property(self):
        return wrap_vtk(self._vtk_obj.GetInnerGridlinesProperty())
    def _set_inner_gridlines_property(self, arg):
        old_val = self._get_inner_gridlines_property()
        self._wrap_call(self._vtk_obj.SetInnerGridlinesProperty,
                        deref_vtk(arg))
        self.trait_property_changed('inner_gridlines_property', old_val, arg)
    inner_gridlines_property = traits.Property(_get_inner_gridlines_property, _set_inner_gridlines_property, help=\
        """
        Get/Set inner gridlines actor property
        """
    )

    def _get_label_text_property(self):
        return wrap_vtk(self._vtk_obj.GetLabelTextProperty())
    def _set_label_text_property(self, arg):
        old_val = self._get_label_text_property()
        self._wrap_call(self._vtk_obj.SetLabelTextProperty,
                        deref_vtk(arg))
        self.trait_property_changed('label_text_property', old_val, arg)
    label_text_property = traits.Property(_get_label_text_property, _set_label_text_property, help=\
        """
        Set/Get the axis labels text property.
        """
    )

    gridline_x_length = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the length to use when drawing gridlines.
        """
    )
    def _gridline_x_length_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetGridlineXLength,
                        self.gridline_x_length)

    minor_start = traits.Float(0.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the starting position for minor and major tick points,
        and the delta values that determine their spacing.
        """
    )
    def _minor_start_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetMinorStart,
                        self.minor_start)

    gridline_y_length = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the length to use when drawing gridlines.
        """
    )
    def _gridline_y_length_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetGridlineYLength,
                        self.gridline_y_length)

    delta_range_major = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the starting position for minor and major tick points on
        the range and the delta values that determine their spacing. The
        range and the position need not be identical. ie the displayed
        values need not match the actual positions in 3d space.
        """
    )
    def _delta_range_major_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetDeltaRangeMajor,
                        self.delta_range_major)

    bounds = traits.Array(shape=(6,), value=(-1.0, 1.0, -1.0, 1.0, -1.0, 1.0), dtype=float, enter_set=True, auto_set=False, cols=3, help=\
        """
        Set or get the bounds for this Actor as
        (Xmin,Xmax,Ymin,Ymax,Zmin,Zmax).
        """
    )
    def _bounds_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetBounds,
                        self.bounds)

    range = traits.Array(shape=(2,), value=(0.0, 1.0), dtype=float, enter_set=True, auto_set=False, cols=3, help=\
        """
        
        """
    )
    def _range_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetRange,
                        self.range)

    def _get_title_text_property(self):
        return wrap_vtk(self._vtk_obj.GetTitleTextProperty())
    def _set_title_text_property(self, arg):
        old_val = self._get_title_text_property()
        self._wrap_call(self._vtk_obj.SetTitleTextProperty,
                        deref_vtk(arg))
        self.trait_property_changed('title_text_property', old_val, arg)
    title_text_property = traits.Property(_get_title_text_property, _set_title_text_property, help=\
        """
        Set/Get the axis title text property.
        """
    )

    def _get_axis_lines_property(self):
        return wrap_vtk(self._vtk_obj.GetAxisLinesProperty())
    def _set_axis_lines_property(self, arg):
        old_val = self._get_axis_lines_property()
        self._wrap_call(self._vtk_obj.SetAxisLinesProperty,
                        deref_vtk(arg))
        self.trait_property_changed('axis_lines_property', old_val, arg)
    axis_lines_property = traits.Property(_get_axis_lines_property, _set_axis_lines_property, help=\
        """
        Get/Set axis actor property (axis and its ticks)
        """
    )

    def get_delta_major(self, *args):
        """
        V.get_delta_major(int) -> float
        C++: double GetDeltaMajor(int axis)"""
        ret = self._wrap_call(self._vtk_obj.GetDeltaMajor, *args)
        return ret

    def set_delta_major(self, *args):
        """
        V.set_delta_major(int, float)
        C++: void SetDeltaMajor(int axis, double value)"""
        ret = self._wrap_call(self._vtk_obj.SetDeltaMajor, *args)
        return ret

    label_format = traits.String(r"%-#6.3g", enter_set=True, auto_set=False, help=\
        """
        Set/Get the format with which to print the labels on the axis.
        """
    )
    def _label_format_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetLabelFormat,
                        self.label_format)

    gridline_z_length = traits.Float(1.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the length to use when drawing gridlines.
        """
    )
    def _gridline_z_length_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetGridlineZLength,
                        self.gridline_z_length)

    use2d_mode = traits.Int(0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the 2d mode
        """
    )
    def _use2d_mode_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetUse2DMode,
                        self.use2d_mode)

    major_range_start = traits.Float(0.0, enter_set=True, auto_set=False, help=\
        """
        Set/Get the starting position for minor and major tick points on
        the range and the delta values that determine their spacing. The
        range and the position need not be identical. ie the displayed
        values need not match the actual positions in 3d space.
        """
    )
    def _major_range_start_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetMajorRangeStart,
                        self.major_range_start)

    save_title_position = traits.Int(0, enter_set=True, auto_set=False, help=\
        """
        Set/Get whether title position must be saved in 2d mode
        """
    )
    def _save_title_position_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetSaveTitlePosition,
                        self.save_title_position)

    def get_major_start(self, *args):
        """
        V.get_major_start(int) -> float
        C++: double GetMajorStart(int axis)
        Set/Get the starting position for minor and major tick points,
        and the delta values that determine their spacing.
        """
        ret = self._wrap_call(self._vtk_obj.GetMajorStart, *args)
        return ret

    def set_major_start(self, *args):
        """
        V.set_major_start(int, float)
        C++: void SetMajorStart(int axis, double value)
        Set/Get the starting position for minor and major tick points,
        and the delta values that determine their spacing.
        """
        ret = self._wrap_call(self._vtk_obj.SetMajorStart, *args)
        return ret

    def _get_number_of_labels_built(self):
        return self._vtk_obj.GetNumberOfLabelsBuilt()
    number_of_labels_built = traits.Property(_get_number_of_labels_built, help=\
        """
        Get total numbe of labels built. Once built this count does not
        change.
        """
    )

    def _get_point1_coordinate(self):
        return wrap_vtk(self._vtk_obj.GetPoint1Coordinate())
    point1_coordinate = traits.Property(_get_point1_coordinate, help=\
        """
        Specify the position of the first point defining the axis.
        """
    )

    def _get_point2_coordinate(self):
        return wrap_vtk(self._vtk_obj.GetPoint2Coordinate())
    point2_coordinate = traits.Property(_get_point2_coordinate, help=\
        """
        Specify the position of the second point defining the axis.
        """
    )

    def _get_title_actor(self):
        return wrap_vtk(self._vtk_obj.GetTitleActor())
    title_actor = traits.Property(_get_title_actor, help=\
        """
        Get title actor and it is responsible for drawing title text.
        """
    )

    def build_axis(self, *args):
        """
        V.build_axis(Viewport, bool)
        C++: void BuildAxis(Viewport *viewport, bool)"""
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.BuildAxis, *my_args)
        return ret

    def compute_max_label_length(self, *args):
        """
        V.compute_max_label_length((float, float, float)) -> float
        C++: double ComputeMaxLabelLength(const double[3])"""
        ret = self._wrap_call(self._vtk_obj.ComputeMaxLabelLength, *args)
        return ret

    def compute_title_length(self, *args):
        """
        V.compute_title_length((float, float, float)) -> float
        C++: double ComputeTitleLength(const double[3])"""
        ret = self._wrap_call(self._vtk_obj.ComputeTitleLength, *args)
        return ret

    def render_translucent_geometry(self, *args):
        """
        V.render_translucent_geometry(Viewport) -> int
        C++: virtual int RenderTranslucentGeometry(Viewport *viewport)
        Draw the axis.
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.RenderTranslucentGeometry, *my_args)
        return ret

    def set_label_scale(self, *args):
        """
        V.set_label_scale(float)
        C++: void SetLabelScale(const double)"""
        ret = self._wrap_call(self._vtk_obj.SetLabelScale, *args)
        return ret

    def set_labels(self, *args):
        """
        V.set_labels(StringArray)
        C++: void SetLabels(StringArray *labels)"""
        my_args = deref_array(args, [['vtkStringArray']])
        ret = self._wrap_call(self._vtk_obj.SetLabels, *my_args)
        return ret

    def set_point1(self, *args):
        """
        V.set_point1([float, float, float])
        C++: virtual void SetPoint1(double x[3])
        V.set_point1(float, float, float)
        C++: virtual void SetPoint1(double x, double y, double z)
        Specify the position of the first point defining the axis.
        """
        ret = self._wrap_call(self._vtk_obj.SetPoint1, *args)
        return ret

    def set_point2(self, *args):
        """
        V.set_point2([float, float, float])
        C++: virtual void SetPoint2(double x[3])
        V.set_point2(float, float, float)
        C++: virtual void SetPoint2(double x, double y, double z)
        Specify the position of the second point defining the axis.
        """
        ret = self._wrap_call(self._vtk_obj.SetPoint2, *args)
        return ret

    def set_title_scale(self, *args):
        """
        V.set_title_scale(float)
        C++: void SetTitleScale(const double)"""
        ret = self._wrap_call(self._vtk_obj.SetTitleScale, *args)
        return ret

    _updateable_traits_ = \
    (('origin', 'GetOrigin'), ('orientation', 'GetOrientation'),
    ('major_tick_size', 'GetMajorTickSize'), ('dragable', 'GetDragable'),
    ('minor_ticks_visible', 'GetMinorTicksVisible'), ('use2d_mode',
    'GetUse2DMode'), ('minor_range_start', 'GetMinorRangeStart'),
    ('label_visibility', 'GetLabelVisibility'), ('axis_position',
    'GetAxisPosition'), ('gridline_y_length', 'GetGridlineYLength'),
    ('horizontal_offset_y_title2d', 'GetHorizontalOffsetYTitle2D'),
    ('scale', 'GetScale'), ('title', 'GetTitle'), ('label_format',
    'GetLabelFormat'), ('minor_start', 'GetMinorStart'),
    ('gridline_x_length', 'GetGridlineXLength'), ('tick_location',
    'GetTickLocation'), ('delta_range_minor', 'GetDeltaRangeMinor'),
    ('axis_visibility', 'GetAxisVisibility'), ('delta_range_major',
    'GetDeltaRangeMajor'), ('vertical_offset_x_title2d',
    'GetVerticalOffsetXTitle2D'), ('allocated_render_time',
    'GetAllocatedRenderTime'), ('minor_tick_size', 'GetMinorTickSize'),
    ('title_visibility', 'GetTitleVisibility'), ('draw_inner_gridlines',
    'GetDrawInnerGridlines'), ('tick_visibility', 'GetTickVisibility'),
    ('visibility', 'GetVisibility'), ('calculate_title_offset',
    'GetCalculateTitleOffset'), ('debug', 'GetDebug'),
    ('render_time_multiplier', 'GetRenderTimeMultiplier'),
    ('draw_gridlines', 'GetDrawGridlines'), ('use_bounds',
    'GetUseBounds'), ('delta_minor', 'GetDeltaMinor'),
    ('calculate_label_offset', 'GetCalculateLabelOffset'),
    ('save_title_position', 'GetSaveTitlePosition'),
    ('estimated_render_time', 'GetEstimatedRenderTime'),
    ('global_warning_display', 'GetGlobalWarningDisplay'), ('axis_type',
    'GetAxisType'), ('draw_gridpolys', 'GetDrawGridpolys'), ('bounds',
    'GetBounds'), ('major_range_start', 'GetMajorRangeStart'), ('range',
    'GetRange'), ('gridline_z_length', 'GetGridlineZLength'),
    ('reference_count', 'GetReferenceCount'), ('position', 'GetPosition'),
    ('pickable', 'GetPickable'))
    
    _full_traitnames_list_ = \
    (['axis_visibility', 'calculate_label_offset',
    'calculate_title_offset', 'debug', 'dragable', 'draw_gridlines',
    'draw_gridpolys', 'draw_inner_gridlines', 'global_warning_display',
    'label_visibility', 'minor_ticks_visible', 'pickable',
    'tick_visibility', 'title_visibility', 'use_bounds', 'visibility',
    'axis_position', 'axis_type', 'tick_location',
    'allocated_render_time', 'bounds', 'delta_minor', 'delta_range_major',
    'delta_range_minor', 'estimated_render_time', 'gridline_x_length',
    'gridline_y_length', 'gridline_z_length',
    'horizontal_offset_y_title2d', 'label_format', 'major_range_start',
    'major_tick_size', 'minor_range_start', 'minor_start',
    'minor_tick_size', 'orientation', 'origin', 'position', 'range',
    'render_time_multiplier', 'save_title_position', 'scale', 'title',
    'use2d_mode', 'vertical_offset_x_title2d'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(AxisActor, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit AxisActor properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View((['axis_visibility', 'calculate_label_offset',
            'calculate_title_offset', 'draw_gridlines', 'draw_gridpolys',
            'draw_inner_gridlines', 'label_visibility', 'minor_ticks_visible',
            'tick_visibility', 'title_visibility', 'use_bounds', 'visibility'],
            ['axis_position', 'axis_type', 'tick_location'],
            ['allocated_render_time', 'bounds', 'delta_minor',
            'delta_range_major', 'delta_range_minor', 'estimated_render_time',
            'gridline_x_length', 'gridline_y_length', 'gridline_z_length',
            'horizontal_offset_y_title2d', 'label_format', 'major_range_start',
            'major_tick_size', 'minor_range_start', 'minor_start',
            'minor_tick_size', 'orientation', 'origin', 'position', 'range',
            'render_time_multiplier', 'save_title_position', 'scale', 'title',
            'use2d_mode', 'vertical_offset_x_title2d']),
            title='Edit AxisActor properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit AxisActor properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

