# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.image_reslice import ImageReslice


class ImageResliceToColors(ImageReslice):
    """
    ImageResliceToColors - Reslice and produce color scalars.
    
    Superclass: ImageReslice
    
    ImageResliceToColors is an extension of ImageReslice that
    produces color scalars.  It should be provided with a lookup table
    that defines the output colors and the desired range of input values
    to map to those colors.  If the input has multiple components, then
    you should use the set_vector_mode() method of the lookup table to
    specify how the vectors will be colored.  If no lookup table is
    provided, then the input must already be color scalars, but they will
    be converted to the specified output format.
    
    See Also:
    
    ImageMapToColors
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkImageResliceToColors, obj, update, **traits)
    
    bypass = tvtk_base.false_bool_trait(help=\
        """
        Bypass the color mapping operation and output the scalar values
        directly.  The output values will be float, rather than the input
        data type.
        """
    )
    def _bypass_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetBypass,
                        self.bypass_)

    output_format = traits.Trait('rgba',
    tvtk_base.TraitRevPrefixMap({'luminance_alpha': 2, 'rgb': 3, 'luminance': 1, 'rgba': 4}), help=\
        """
        Set the output format, the default is RGBA.
        """
    )
    def _output_format_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetOutputFormat,
                        self.output_format_)

    def _get_lookup_table(self):
        return wrap_vtk(self._vtk_obj.GetLookupTable())
    def _set_lookup_table(self, arg):
        old_val = self._get_lookup_table()
        self._wrap_call(self._vtk_obj.SetLookupTable,
                        deref_vtk(arg))
        self.trait_property_changed('lookup_table', old_val, arg)
    lookup_table = traits.Property(_get_lookup_table, _set_lookup_table, help=\
        """
        Set a lookup table to apply to the data.  Use the Range,
        vector_mode, and vector_components of the table to control the
        mapping of the input data to colors.  If any output voxel is
        transformed to a point outside the input volume, then that voxel
        will be set to the background_color.
        """
    )

    _updateable_traits_ = \
    (('auto_crop_output', 'GetAutoCropOutput'), ('release_data_flag',
    'GetReleaseDataFlag'), ('output_format', 'GetOutputFormat'),
    ('generate_stencil_output', 'GetGenerateStencilOutput'),
    ('interpolate', 'GetInterpolate'), ('slab_mode', 'GetSlabMode'),
    ('debug', 'GetDebug'), ('output_extent', 'GetOutputExtent'),
    ('reslice_axes_origin', 'GetResliceAxesOrigin'), ('mirror',
    'GetMirror'), ('wrap', 'GetWrap'), ('output_dimensionality',
    'GetOutputDimensionality'), ('background_color',
    'GetBackgroundColor'), ('transform_input_sampling',
    'GetTransformInputSampling'), ('slab_trapezoid_integration',
    'GetSlabTrapezoidIntegration'), ('background_level',
    'GetBackgroundLevel'), ('global_warning_display',
    'GetGlobalWarningDisplay'), ('output_spacing', 'GetOutputSpacing'),
    ('border', 'GetBorder'), ('bypass', 'GetBypass'), ('progress_text',
    'GetProgressText'), ('output_origin', 'GetOutputOrigin'),
    ('optimization', 'GetOptimization'),
    ('reslice_axes_direction_cosines', 'GetResliceAxesDirectionCosines'),
    ('number_of_threads', 'GetNumberOfThreads'), ('reference_count',
    'GetReferenceCount'), ('progress', 'GetProgress'), ('abort_execute',
    'GetAbortExecute'), ('interpolation_mode', 'GetInterpolationMode'),
    ('slab_number_of_slices', 'GetSlabNumberOfSlices'))
    
    _full_traitnames_list_ = \
    (['abort_execute', 'auto_crop_output', 'border', 'bypass', 'debug',
    'generate_stencil_output', 'global_warning_display', 'interpolate',
    'mirror', 'optimization', 'release_data_flag',
    'slab_trapezoid_integration', 'transform_input_sampling', 'wrap',
    'interpolation_mode', 'output_format', 'slab_mode',
    'background_color', 'background_level', 'number_of_threads',
    'output_dimensionality', 'output_extent', 'output_origin',
    'output_spacing', 'progress_text', 'reslice_axes_direction_cosines',
    'reslice_axes_origin', 'slab_number_of_slices'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(ImageResliceToColors, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit ImageResliceToColors properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View((['auto_crop_output', 'border', 'bypass',
            'generate_stencil_output', 'interpolate', 'mirror', 'optimization',
            'slab_trapezoid_integration', 'transform_input_sampling', 'wrap'],
            ['interpolation_mode', 'output_format', 'slab_mode'],
            ['background_color', 'background_level', 'number_of_threads',
            'output_dimensionality', 'output_extent', 'output_origin',
            'output_spacing', 'reslice_axes_direction_cosines',
            'reslice_axes_origin', 'slab_number_of_slices']),
            title='Edit ImageResliceToColors properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit ImageResliceToColors properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

