# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.context_item import ContextItem


class Plot(ContextItem):
    """
    Plot - Abstract class for 2d plots.
    
    Superclass: ContextItem
    
    The base class for all plot types used in Chart derived charts.
    
    See Also:
    
    PlotPoints PlotLine PlotBar Chart ChartXY
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkPlot, obj, update, **traits)
    
    use_index_for_x_series = traits.Bool(False, help=\
        """
        Use the Y array index for the X value. If true any X column
        setting will be ignored, and the X values will simply be the
        index of the Y column.
        """
    )
    def _use_index_for_x_series_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetUseIndexForXSeries,
                        self.use_index_for_x_series)

    def _get_labels(self):
        return wrap_vtk(self._vtk_obj.GetLabels())
    def _set_labels(self, arg):
        old_val = self._get_labels()
        my_arg = deref_array([arg], [['vtkStringArray']])
        self._wrap_call(self._vtk_obj.SetLabels,
                        my_arg[0])
        self.trait_property_changed('labels', old_val, arg)
    labels = traits.Property(_get_labels, _set_labels, help=\
        """
        Get the plot labels. If this array has a length greater than 1
        the index refers to the stacked objects in the plot. See
        PlotBar for example.
        """
    )

    def _get_x_axis(self):
        return wrap_vtk(self._vtk_obj.GetXAxis())
    def _set_x_axis(self, arg):
        old_val = self._get_x_axis()
        self._wrap_call(self._vtk_obj.SetXAxis,
                        deref_vtk(arg))
        self.trait_property_changed('x_axis', old_val, arg)
    x_axis = traits.Property(_get_x_axis, _set_x_axis, help=\
        """
        Get/set the X axis associated with this plot.
        """
    )

    def _get_y_axis(self):
        return wrap_vtk(self._vtk_obj.GetYAxis())
    def _set_y_axis(self, arg):
        old_val = self._get_y_axis()
        self._wrap_call(self._vtk_obj.SetYAxis,
                        deref_vtk(arg))
        self.trait_property_changed('y_axis', old_val, arg)
    y_axis = traits.Property(_get_y_axis, _set_y_axis, help=\
        """
        Get/set the Y axis associated with this plot.
        """
    )

    def get_color(self, *args):
        """
        V.get_color([float, float, float])
        C++: virtual void GetColor(double rgb[3])
        V.get_color([int, int, int])
        C++: void GetColor(unsigned char rgb[3])
        Set the plot color
        """
        ret = self._wrap_call(self._vtk_obj.GetColor, *args)
        return ret

    def set_color(self, *args):
        """
        V.set_color(int, int, int, int)
        C++: virtual void SetColor(unsigned char r, unsigned char g,
            unsigned char b, unsigned char a)
        V.set_color(float, float, float)
        C++: virtual void SetColor(double r, double g, double b)
        Set the plot color
        """
        ret = self._wrap_call(self._vtk_obj.SetColor, *args)
        return ret

    def _get_indexed_labels(self):
        return wrap_vtk(self._vtk_obj.GetIndexedLabels())
    def _set_indexed_labels(self, arg):
        old_val = self._get_indexed_labels()
        my_arg = deref_array([arg], [['vtkStringArray']])
        self._wrap_call(self._vtk_obj.SetIndexedLabels,
                        my_arg[0])
        self.trait_property_changed('indexed_labels', old_val, arg)
    indexed_labels = traits.Property(_get_indexed_labels, _set_indexed_labels, help=\
        """
        Get the indexed labels array.
        """
    )

    label = traits.String(r"", enter_set=True, auto_set=False, help=\
        """
        Set the label of this plot.
        """
    )
    def _label_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetLabel,
                        self.label)

    width = traits.Float(2.0, enter_set=True, auto_set=False, help=\
        """
        Set the width of the line.
        """
    )
    def _width_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetWidth,
                        self.width)

    def _get_pen(self):
        return wrap_vtk(self._vtk_obj.GetPen())
    def _set_pen(self, arg):
        old_val = self._get_pen()
        self._wrap_call(self._vtk_obj.SetPen,
                        deref_vtk(arg))
        self.trait_property_changed('pen', old_val, arg)
    pen = traits.Property(_get_pen, _set_pen, help=\
        """
        Set/get the Pen object that controls how this plot draws
        (out)lines.
        """
    )

    def _get_selection(self):
        return wrap_vtk(self._vtk_obj.GetSelection())
    def _set_selection(self, arg):
        old_val = self._get_selection()
        my_arg = deref_array([arg], [['vtkIdTypeArray']])
        self._wrap_call(self._vtk_obj.SetSelection,
                        my_arg[0])
        self.trait_property_changed('selection', old_val, arg)
    selection = traits.Property(_get_selection, _set_selection, help=\
        """
        
        """
    )

    def _get_brush(self):
        return wrap_vtk(self._vtk_obj.GetBrush())
    def _set_brush(self, arg):
        old_val = self._get_brush()
        self._wrap_call(self._vtk_obj.SetBrush,
                        deref_vtk(arg))
        self.trait_property_changed('brush', old_val, arg)
    brush = traits.Property(_get_brush, _set_brush, help=\
        """
        Set/get the Brush object that controls how this plot fills
        shapes.
        """
    )

    tooltip_label_format = traits.String(r"", enter_set=True, auto_set=False, help=\
        """
        Sets/gets a printf-style string to build custom tooltip labels
        from. An empty string generates the default tooltip labels. The
        following case-sensitive format tags (without quotes) are
        recognized:
          '%x' The X value of the plot element
          '%y' The Y value of the plot element
          '%i' The indexed_labels entry for the plot element
          '%l' The value of the plot's get_label() function
          '%s' (vtk_plot_bar only) The Labels entry for the bar segment Any
        other characters or unrecognized format tags are printed in the
        tooltip label verbatim.
        """
    )
    def _tooltip_label_format_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTooltipLabelFormat,
                        self.tooltip_label_format)

    def _get_input(self):
        try:
            return wrap_vtk(self._vtk_obj.GetInput(0))
        except TypeError:
            return wrap_vtk(self._vtk_obj.GetInput())
    def _set_input(self, obj):
        old_val = self._get_input()
        self._wrap_call(self._vtk_obj.SetInput, deref_vtk(obj))
        self.trait_property_changed('input', old_val, obj)
    input = traits.Property(_get_input, _set_input,
                            help="The first input of this object, i.e. the result of `get_input(0)`.")
    
    def get_input(self):
        """
        V.get_input() -> Table
        C++: virtual Table *GetInput()
        Get the input table used by the plot.
        """
        ret = wrap_vtk(self._vtk_obj.GetInput())
        return ret
        

    def set_input(self, *args):
        """
        V.set_input(Table)
        C++: virtual void SetInput(Table *table)
        V.set_input(Table, string, string)
        C++: virtual void SetInput(Table *table,
            const StdString &xColumn, const StdString &yColumn)
        V.set_input(Table, int, int)
        C++: void SetInput(Table *table, IdType xColumn,
            IdType yColumn)
        This is a convenience function to set the input table and the x,
        y column for the plot.
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.SetInput, *my_args)
        return ret

    def get_property(self, *args):
        """
        V.get_property(string) -> Variant
        C++: virtual Variant GetProperty(const StdString &property)
        A General setter/getter that should be overridden. It can
        silently drop options, case is important
        """
        ret = self._wrap_call(self._vtk_obj.GetProperty, *args)
        return wrap_vtk(ret)

    def set_property(self, *args):
        """
        V.set_property(string, Variant)
        C++: virtual void SetProperty(const StdString &property,
            const Variant &var)
        A General setter/getter that should be overridden. It can
        silently drop options, case is important
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.SetProperty, *my_args)
        return ret

    tooltip_notation = traits.Int(0, enter_set=True, auto_set=False, help=\
        """
        Sets/gets the tooltip notation style.
        """
    )
    def _tooltip_notation_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTooltipNotation,
                        self.tooltip_notation)

    tooltip_precision = traits.Int(6, enter_set=True, auto_set=False, help=\
        """
        Sets/gets the tooltip precision.
        """
    )
    def _tooltip_precision_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetTooltipPrecision,
                        self.tooltip_precision)

    def get_bounds(self, *args):
        """
        V.get_bounds([float, float, float, float])
        C++: virtual void GetBounds(double bounds[4])
        Get the bounds for this plot as (Xmin, Xmax, Ymin, Ymax).
        """
        ret = self._wrap_call(self._vtk_obj.GetBounds, *args)
        return ret

    def _get_data(self):
        return wrap_vtk(self._vtk_obj.GetData())
    data = traits.Property(_get_data, help=\
        """
        Get the data object that the plot will draw.
        """
    )

    def _get_number_of_labels(self):
        return self._vtk_obj.GetNumberOfLabels()
    number_of_labels = traits.Property(_get_number_of_labels, help=\
        """
        Get the number of labels associated with this plot.
        """
    )

    def get_tooltip_label(self, *args):
        """
        V.get_tooltip_label(Vector2f, int, int) -> string
        C++: virtual StdString GetTooltipLabel(
            const Vector2f &plotPos, IdType seriesIndex,
            IdType segmentIndex)
        Generate and return the tooltip label string for this plot The
        segment_index parameter is ignored, except for PlotBar
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.GetTooltipLabel, *my_args)
        return ret

    def paint_legend(self, *args):
        """
        V.paint_legend(Context2D, Rectf, int) -> bool
        C++: virtual bool PaintLegend(Context2D *painter,
            const Rectf &rect, int legendIndex)
        Paint legend event for the plot, called whenever the legend needs
        the plot items symbol/mark/line drawn. A rect is supplied with
        the lower left corner of the rect (elements 0 and 1) and with
        width x height (elements 2 and 3). The plot can choose how to
        fill the space supplied. The index is used by Plots that return
        more than one label.
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.PaintLegend, *my_args)
        return ret

    def select_points(self, *args):
        """
        V.select_points(Vector2f, Vector2f) -> bool
        C++: virtual bool SelectPoints(const Vector2f &min,
            const Vector2f &max)
        Select all points in the specified rectangle.
        """
        my_args = [deref_vtk(x) for x in args]
        ret = self._wrap_call(self._vtk_obj.SelectPoints, *my_args)
        return ret

    def set_input_array(self, *args):
        """
        V.set_input_array(int, string)
        C++: virtual void SetInputArray(int index,
            const StdString &name)
        Convenience function to set the input arrays. For most plots
        index 0 is the x axis, and index 1 is the y axis. The name is the
        name of the column in the Table.
        """
        ret = self._wrap_call(self._vtk_obj.SetInputArray, *args)
        return ret

    _updateable_traits_ = \
    (('opacity', 'GetOpacity'), ('use_index_for_x_series',
    'GetUseIndexForXSeries'), ('global_warning_display',
    'GetGlobalWarningDisplay'), ('width', 'GetWidth'), ('debug',
    'GetDebug'), ('label', 'GetLabel'), ('visible', 'GetVisible'),
    ('tooltip_notation', 'GetTooltipNotation'), ('reference_count',
    'GetReferenceCount'), ('tooltip_precision', 'GetTooltipPrecision'),
    ('tooltip_label_format', 'GetTooltipLabelFormat'))
    
    _full_traitnames_list_ = \
    (['debug', 'global_warning_display', 'label', 'opacity',
    'tooltip_label_format', 'tooltip_notation', 'tooltip_precision',
    'use_index_for_x_series', 'visible', 'width'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(Plot, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit Plot properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View(([], [], ['label', 'opacity', 'tooltip_label_format',
            'tooltip_notation', 'tooltip_precision', 'use_index_for_x_series',
            'visible', 'width']),
            title='Edit Plot properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit Plot properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

