# Automatically generated code: EDIT AT YOUR OWN RISK
from traits import api as traits
from traitsui import api as traitsui

from tvtk import vtk_module as vtk
from tvtk import tvtk_base
from tvtk.tvtk_base_handler import TVTKBaseHandler
from tvtk import messenger
from tvtk.tvtk_base import deref_vtk
from tvtk import array_handler
from tvtk.array_handler import deref_array
from tvtk.tvtk_classes.tvtk_helper import wrap_vtk

from tvtk.tvtk_classes.video_source import VideoSource


class Win32VideoSource(VideoSource):
    """
    Win32VideoSource - Video-for-Windows video digitizer
    
    Superclass: VideoSource
    
    Win32VideoSource grabs frames or streaming video from a Video for
    Windows compatible device on the Win32 platform.
    
    Caveats:
    
    With some capture cards, if this class is leaked and
    release_system_resources is not called, you may have to reboot before
    you can capture again. VideoSource used to keep a global list and
    delete the video sources if your program leaked, due to exit crashes
    that was removed.
    
    See Also:
    
    VideoSource MILVideoSource
    
    """
    def __init__(self, obj=None, update=True, **traits):
        tvtk_base.TVTKBase.__init__(self, vtk.vtkWin32VideoSource, obj, update, **traits)
    
    preview = tvtk_base.false_bool_trait(help=\
        """
        Turn on/off the preview (overlay) window.
        """
    )
    def _preview_changed(self, old_val, new_val):
        self._do_change(self._vtk_obj.SetPreview,
                        self.preview_)

    def local_internal_grab(self):
        """
        V.local_internal_grab()
        C++: void LocalInternalGrab(void *)
        For internal use only
        """
        ret = self._vtk_obj.LocalInternalGrab()
        return ret
        

    def on_parent_wnd_destroy(self):
        """
        V.on_parent_wnd_destroy()
        C++: void OnParentWndDestroy()
        For internal use only
        """
        ret = self._vtk_obj.OnParentWndDestroy()
        return ret
        

    def video_format_dialog(self):
        """
        V.video_format_dialog()
        C++: void VideoFormatDialog()
        Bring up a modal dialog box for video format selection.
        """
        ret = self._vtk_obj.VideoFormatDialog()
        return ret
        

    def video_source_dialog(self):
        """
        V.video_source_dialog()
        C++: void VideoSourceDialog()
        Bring up a modal dialog box for video input selection.
        """
        ret = self._vtk_obj.VideoSourceDialog()
        return ret
        

    _updateable_traits_ = \
    (('opacity', 'GetOpacity'), ('output_whole_extent',
    'GetOutputWholeExtent'), ('release_data_flag', 'GetReleaseDataFlag'),
    ('clip_region', 'GetClipRegion'), ('progress_text',
    'GetProgressText'), ('auto_advance', 'GetAutoAdvance'),
    ('number_of_output_frames', 'GetNumberOfOutputFrames'), ('debug',
    'GetDebug'), ('data_spacing', 'GetDataSpacing'), ('abort_execute',
    'GetAbortExecute'), ('start_time_stamp', 'GetStartTimeStamp'),
    ('frame_rate', 'GetFrameRate'), ('frame_size', 'GetFrameSize'),
    ('reference_count', 'GetReferenceCount'), ('progress', 'GetProgress'),
    ('output_format', 'GetOutputFormat'), ('preview', 'GetPreview'),
    ('frame_count', 'GetFrameCount'), ('frame_buffer_size',
    'GetFrameBufferSize'), ('data_origin', 'GetDataOrigin'),
    ('global_warning_display', 'GetGlobalWarningDisplay'))
    
    _full_traitnames_list_ = \
    (['abort_execute', 'auto_advance', 'debug', 'global_warning_display',
    'preview', 'release_data_flag', 'output_format', 'clip_region',
    'data_origin', 'data_spacing', 'frame_buffer_size', 'frame_count',
    'frame_rate', 'frame_size', 'number_of_output_frames', 'opacity',
    'output_whole_extent', 'progress_text', 'start_time_stamp'])
    
    def trait_view(self, name=None, view_element=None):
        if view_element is not None or name not in (None, '', 'traits_view', 'full_traits_view', 'view'):
            return super(Win32VideoSource, self).trait_view(name, view_element)
        if name == 'full_traits_view':
            full_traits_view = \
            traitsui.View((traitsui.Item("handler._full_traits_list",show_label=False)),
            title='Edit Win32VideoSource properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return full_traits_view
        elif name == 'view':
            view = \
            traitsui.View((['auto_advance', 'preview'], ['output_format'],
            ['clip_region', 'data_origin', 'data_spacing', 'frame_buffer_size',
            'frame_count', 'frame_rate', 'frame_size', 'number_of_output_frames',
            'opacity', 'output_whole_extent', 'start_time_stamp']),
            title='Edit Win32VideoSource properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return view
        elif name in (None, 'traits_view'):
            traits_view = \
            traitsui.View((traitsui.HGroup(traitsui.spring, "handler.view_type", show_border=True), 
            traitsui.Item("handler.info.object", editor = traitsui.InstanceEditor(view_name="handler.view"), style = "custom", show_label=False)),
            title='Edit Win32VideoSource properties', scrollable=True, resizable=True,
            handler=TVTKBaseHandler,
            buttons=['OK', 'Cancel'])
            return traits_view
            

